@@ -6,7 +6,7 @@ app_state = st.experimental_get_query_params()
 app_state = {k: v[0] if isinstance(v, list) else v for k, v in app_state.items()} 
 
 rhost,rport,rdb		= app_state.get('rhost','172.17.0.1') , app_state.get('rport',6379), app_state.get('rdb', 0)
-xname				= app_state.get('xname','xgecdsk:rid-tid-uid')
+xname				= app_state.get('xname','xdsk:rid-tid-uid') #xgecdsk
 debug				= 'debug' in app_state
 if not hasattr(redis, 'r'): redis.r	= redis.Redis(host=rhost, port=rport, db=rdb, decode_responses=True)
 
