@@ -17,8 +17,9 @@ def run():
 		score = round(100 * len([snt for snt, refer in zip(labels, refers) if snt == refer]) / len(snts), 2)
 		st.metric("SCORE", score )
 		redis.r.hset(f"rid-{rid}:tid-{tid}:uid-{uid}","score", score, {"rid": rid, "tid": tid,"uid": uid, "type":"restore" } )
-		redis.r.hset(f"score:rid-{rid}:tid-{tid}", f"rid-{rid}:tid-{tid}:uid-{uid}", score) # verbose, for counting convenience
+		redis.r.hset(f"score:rid-{rid}:tid-{tid}", uid, score) # verbose, for counting convenience
 		for i, label in enumerate(labels): 
 			redis.r.hset(f"rid-{rid}:tid-{tid}:uid-{uid}",f"label-{i}", label, {f"score-{i}": 1 if label == refers[i] else 0} )
+			#redis.r.hset(f"rid-{rid}:tid-{tid}:uid-{uid}",f"label-{i+1}", label, {f"score-{i+1}": 1 if label == refers[i] else 0} )
 
 if __name__ == '__main__': run()
\ No newline at end of file
