@@ -1,4 +1,4 @@
-# 2022.6.8
+# 2022.6.17
 from common import *
 
 def run():
@@ -11,4 +11,9 @@ def run():
 		redis.r.hset(f"rid-{rid}:tid-{tid}:uid-{uid}","score", score, {"rid": rid, "tid": tid,"uid": uid, "type":"scoring"} )
 		st.metric("SCORE", score )
 
-if __name__ == '__main__': run()
+		# to be removed when can get in grafana, to compute Max/Min
+		redis.r.hset(f"score:rid-{rid}:tid-{tid}", uid, score)  
+		scores = [ float(s) for s in redis.r.hvals(f"score:rid-{rid}:tid-{tid}")]
+		if scores: redis.r.hset(f"score:rid-{rid}:tid-{tid}:avg", "avg", round(sum(scores)/ (len(scores)+0.00001),2), {"max": max(scores), "min": min(scores)} )
+
+if __name__ == '__main__': run()
\ No newline at end of file
