@@ -12,7 +12,7 @@ def run():
 		id = redis.r.xadd(xname, {"rid": rid, "tid": tid,"uid": uid, "essay_or_snts": essay, "submit": 1})
 		if debug:  st.sidebar.write( redis.r.xrevrange(xname, count=1))
 
-		res = redis.r.blpop(f"gecdsk:{id}", timeout=app_state.get('timeout',5))
+		res = redis.r.blpop(f"xdsk:{id}", timeout=app_state.get('timeout',5))
 		if debug: st.sidebar.write(res)  
 		if res: st.metric("SCORE", round(float(json.loads(res[1]).get('info',{}).get("final_score",0)), 2) )
 
