@@ -2,13 +2,15 @@
 # 2022.2.13 created 
 import requests,json, os, math,re,traceback
 from elasticsearch import Elasticsearch,helpers
-from collections import	Counter
+from collections import	defaultdict, Counter
+import pandas as pd 
 import warnings
 warnings.filterwarnings("ignore")
 
-eshost	= os.getenv("eshost", "127.0.0.1") 
-esport	= int(os.getenv("esport", 9200))
-#requests.put(f"http://{eshost}:{esport}/_cluster/settings", json={"persistent": {"search.max_buckets": 1000000}}).text
+if not hasattr(requests, 'eshost'):
+	requests.eshost	= os.getenv("eshost", "172.17.0.1") 
+	requests.esport	= int(os.getenv("esport", 9200))
+	requests.es		= Elasticsearch([ f"http://{requests.eshost}:{requests.esport}" ])  
 
 config = {  
 		"settings" : {
@@ -229,20 +231,18 @@ config = {
 		}
 	}
 
-#if eshost: 
-es		= Elasticsearch([ f"http://{eshost}:{esport}" ])  
-newindex= lambda idxname : (es.indices.delete(idxname) if es.indices.exists(idxname) else None, es.indices.create(idxname, config))[1] # body=
-rows	= lambda query: requests.post(f"http://{eshost}:{esport}/_sql",json={"query": query}).json().get('rows',[]) 
-sql		= lambda query: requests.post(f"http://{eshost}:{esport}/_sql",json={"query": query}).json().get('rows',[]) 
+newindex= lambda idxname : (requests.es.indices.delete(idxname) if requests.es.indices.exists(idxname) else None, requests.es.indices.create(idxname, config))[1] # body=
+rows	= lambda query: requests.post(f"http://{requests.eshost}:{requests.esport}/_sql",json={"query": query}).json().get('rows',[]) 
+sql		= lambda query: requests.post(f"http://{requests.eshost}:{requests.esport}/_sql",json={"query": query}).json().get('rows',[]) 
 sntnum	= lambda cp: sql(f"select count(*) cnt from {cp} where type = 'snt'" )[0][0] #75222
 lexnum	= lambda w,cp: sql(f"select count(*) cnt from {cp} where low = '{w}' and type = 'tok'")[0][0] # opened = 70
 lemnum	= lambda w,cp: sql(f"select count(*) cnt from {cp} where lem = '{w}' and type = 'tok'")[0][0] 
 sqlsi	= lambda query: (si:=Counter(), [si.update({row[0]:1}) for row in sql(query)])[0]
-warmup  = lambda : requests.put(f"http://{eshost}:{esport}/_cluster/settings", json={"persistent": {"search.max_buckets": 1000000}}).text
+warmup  = lambda : requests.put(f"http://{requests.eshost}:{requests.esport}/_cluster/settings", json={"persistent": {"search.max_buckets": 1000000}}).text
 
 def sqlrow(query="select lem, count(*) cnt  from gzjc where type = 'tok' and pos != 'PUNCT' group by lem order by cnt desc limit 10"):
 	''' {'columns': [{'name': 'lem', 'type': 'keyword'}, {'name': 'cnt', 'type': 'long'}], 'rows': [['the', 7552], ['be', 5640], ['and', 3604], ['to', 3561], ['of', 3127], ['a', 2902], ['in', 2687], ['I', 2063], ['have', 1562], ['it', 1311]]} '''
-	res = requests.post(f"http://{eshost}:{esport}/_sql",json={"query": query}).json() 
+	res = requests.post(f"http://{requests.eshost}:{requests.esport}/_sql",json={"query": query}).json() 
 	columns = [ ar['name'] for ar in res['columns'] ]
 	return  [  dict(zip(columns, ar)) for ar in res['rows'] ] #[{'lem': 'the', 'cnt': 7552}, {'lem': 'be', 'cnt': 5640}, {'lem': 'and', 'cnt': 3604}, {'lem': 'to', 'cnt': 3561}, {'lem': 'of', 'cnt': 3127}, {'lem': 'a', 'cnt': 2902}, {'lem': 'in', 'cnt': 2687}, {'lem': 'I', 'cnt': 2063}, {'lem': 'have', 'cnt': 1562}, {'lem': 'it', 'cnt': 1311}]
 
@@ -269,21 +269,21 @@ def likelihood(a,b,c,d, minus=None):  #from: http://ucrel.lancs.ac.uk/llwizard.h
 #PUT twitter/_mapping {  "properties": {  "email": { "type": "keyword"  }  }}
 #"stroke": { "type": "keyword", "index": "false"},
 def delete_index(cp:str='testidx'): 
-	return requests.delete(f"http://{eshost}:{esport}/{cp}").text #DELETE /twitter
+	return requests.delete(f"http://{requests.eshost}:{requests.esport}/{cp}").text #DELETE /twitter
 def new_empty_index(cp:str='testidx', delete:bool=True): 
-	if delete: requests.delete(f"http://{eshost}:{esport}/{cp}").text
-	return requests.put(f"http://{eshost}:{esport}/{cp}", data={}).text #PUT twitter  {}
+	if delete: requests.delete(f"http://{requests.eshost}:{requests.esport}/{cp}").text
+	return requests.put(f"http://{requests.eshost}:{requests.esport}/{cp}", data={}).text #PUT twitter  {}
 def add_mapping_keyword(kws:list, cp:str='testidx'): 
-	return [requests.put(f"http://{eshost}:{esport}/{cp}/_mapping/", data={"properties": {  f"{kw}": { "type": "keyword"  }  }}).text for kw in kws]
+	return [requests.put(f"http://{requests.eshost}:{requests.esport}/{cp}/_mapping/", data={"properties": {  f"{kw}": { "type": "keyword"  }  }}).text for kw in kws]
 def add_mapping_keyword_noindex(kws:list, cp:str='testidx'): 
-	return [requests.put(f"http://{eshost}:{esport}/{cp}/_mapping/", data={"properties": {  f"{kw}": { "type": "keyword", "index": "false"} }}).text for kw in kws]
+	return [requests.put(f"http://{requests.eshost}:{requests.esport}/{cp}/_mapping/", data={"properties": {  f"{kw}": { "type": "keyword", "index": "false"} }}).text for kw in kws]
 def add_mapping_float(kws:list, cp:str='testidx'): 
-	return [requests.put(f"http://{eshost}:{esport}/{cp}/_mapping/", data={"properties": {  f"{kw}": { "type": "float"  }  }}).text for kw in kws]
+	return [requests.put(f"http://{requests.eshost}:{requests.esport}/{cp}/_mapping/", data={"properties": {  f"{kw}": { "type": "float"  }  }}).text for kw in kws]
 def add_mapping_integer(kws:list, cp:str='testidx'): 
-	return [requests.put(f"http://{eshost}:{esport}/{cp}/_mapping/", data={"properties": {  f"{kw}": { "type": "integer"  }  }}).text for kw in kws]
+	return [requests.put(f"http://{requests.eshost}:{requests.esport}/{cp}/_mapping/", data={"properties": {  f"{kw}": { "type": "integer"  }  }}).text for kw in kws]
 def add_mapping(dic:dict, cp:str='testidx'): 
 	''' {"num":"integer", "awl":"float", "tag":"keyword"} '''
-	return [requests.put(f"http://{eshost}:{esport}/{cp}/_mapping/", data={"properties": {  f"{k}": { "type": "{v}"  }  }}).text for k,v in dic.items()]
+	return [requests.put(f"http://{requests.eshost}:{requests.esport}/{cp}/_mapping/", data={"properties": {  f"{k}": { "type": "{v}"  }  }}).text for k,v in dic.items()]
 
 def bulk(arr, batch=100000, debug=False):
 	''' bulk submit , added 2022.3.27, not tested yet '''
@@ -313,10 +313,10 @@ def ids(_ids:list, cp:str='inau'):
 			}
 		}
 	}
-	return requests.post(f"http://{eshost}:{esport}/{cp}/_search/", json=sql).json()
+	return requests.post(f"http://{requests.eshost}:{requests.esport}/{cp}/_search/", json=sql).json()
 
 def term_to_snts(sql): 
-	rows = es.sql(sql) #f"select src from {cp} where type = 'trp' and gov='{gov}' and rel='{rel}' and dep='{dep}' limit {topk}"
+	rows = requests.es.sql(sql) #f"select src from {cp} where type = 'trp' and gov='{gov}' and rel='{rel}' and dep='{dep}' limit {topk}"
 	sql	= {
     "query": {
         "ids" : {
@@ -325,7 +325,7 @@ def term_to_snts(sql):
 			}
 		}
 	}
-	return requests.post(f"http://{eshost}:{esport}/{cp}/_search/", json=sql).json()
+	return requests.post(f"http://{requests.eshost}:{requests.esport}/{cp}/_search/", json=sql).json()
 
 def match_phrase(phrase:str='opened the box', cp:str='clec', topk:int=10): 
 	''' '''
@@ -337,7 +337,7 @@ def match_phrase(phrase:str='opened the box', cp:str='clec', topk:int=10):
   }
   , "size": topk
 }
-	return requests.post(f"http://{eshost}:{esport}/{cp}/_search/", json=sql).json()
+	return requests.post(f"http://{requests.eshost}:{requests.esport}/{cp}/_search/", json=sql).json()
 
 phrase_num = lambda phrase, cp='clec', topk=10: match_phrase(phrase, cp, topk)["hits"]["total"]["value"]
 
@@ -357,7 +357,7 @@ def hybchunk(hyb:str='the _NNS of', index:str='gzjc', size:int= -1, topk:int=10)
   },
   "size":  size
 }
-	res = requests.post(f"http://{eshost}:{esport}/{index}/_search/", json=sql).json()
+	res = requests.post(f"http://{requests.eshost}:{requests.esport}/{index}/_search/", json=sql).json()
 	si = Counter()
 	repat = rehyb(hyb)
 	for ar in res['hits']['hits']: 
@@ -367,7 +367,6 @@ def hybchunk(hyb:str='the _NNS of', index:str='gzjc', size:int= -1, topk:int=10)
 	return si.most_common(topk)
 
 if __name__ == "__main__": 
-	print(es)
 	print ( sql("select lem, count(*) cnt  from gzjc where type = 'tok' and pos != 'PUNCT' group by lem order by cnt desc limit 10"))
 	print ( sqlrow("show tables")) 
 
@@ -436,7 +435,7 @@ GET /my_index/_search
 
 essaydm.wrask.com 
 ubuntu@VM-171-3-ubuntu:/data$ runlike es
-docker run --name=es --hostname=db25101107b8 --user=elasticsearch --mac-address=02:42:ac:12:00:02 --env=discovery.type=single-node --env=PATH=/usr/local/openjdk-11/bin:/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin --env=LANG=C.UTF-8 --env=JAVA_HOME=/usr/local/openjdk-11 --env=JAVA_VERSION=11.0.9.1 --env=EK_VERSION=7.15.1 --volume=/ftp/es-9200-eevsnts:/home/elasticsearch/elasticsearch-7.15.1/data --workdir=/home/elasticsearch -p 5601:5601 -p 9200:{esport} --restart=always --label='maintainer=nshou <nshou@coronocoya.net>' --runtime=runc --detach=true nshou/elasticsearch-kibana /bin/sh -c 'elasticsearch-${EK_VERSION}/bin/elasticsearch -E http.host=0.0.0.0 --quiet & kibana-${EK_VERSION}-linux-x86_64/bin/kibana --allow-root --host 0.0.0.0 -Q'
+docker run --name=es --hostname=db25101107b8 --user=elasticsearch --mac-address=02:42:ac:12:00:02 --env=discovery.type=single-node --env=PATH=/usr/local/openjdk-11/bin:/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin --env=LANG=C.UTF-8 --env=JAVA_HOME=/usr/local/openjdk-11 --env=JAVA_VERSION=11.0.9.1 --env=EK_VERSION=7.15.1 --volume=/ftp/es-9200-eevsnts:/home/elasticsearch/elasticsearch-7.15.1/data --workdir=/home/elasticsearch -p 5601:5601 -p 9200:{requests.esport} --restart=always --label='maintainer=nshou <nshou@coronocoya.net>' --runtime=runc --detach=true nshou/elasticsearch-kibana /bin/sh -c 'elasticsearch-${EK_VERSION}/bin/elasticsearch -E http.host=0.0.0.0 --quiet & kibana-${EK_VERSION}-linux-x86_64/bin/kibana --allow-root --host 0.0.0.0 -Q'
 
 #https://www.elastic.co/cn/blog/introducing-approximate-nearest-neighbor-search-in-elasticsearch-8-0
 
